==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/rpc/StationDashboardService.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Private**
 * @module nmodule/nss/rc/rpc/StationDashboardService
 */
define(['nmodule/js/rc/tinyevents/tinyevents', 'nmodule/nss/rc/rpc/rpc'], function (tinyevents, rpc) {
  'use strict';

  /**
   * @class
   * @alias module:nmodule/nss/rc/rpc/StationDashboardService
   * @implements module:nmodule/nss/rc/rpc/rpc.IDashboardService
   * @mixes tinyevents
   */
  return /*#__PURE__*/function () {
    function StationDashboardService() {
      _classCallCheck(this, StationDashboardService);
      tinyevents(this);
    }
    return _createClass(StationDashboardService, [{
      key: "getSourceCollection",
      value: function getSourceCollection(ord) {
        return rpc.getStationData(ord);
      }
    }, {
      key: "getItemCollection",
      value: function getItemCollection(ord) {
        var _this = this;
        return rpc.getStationItemCollection(ord).then(function (itemCollection) {
          _this.emit('itemCollectionUpdated', itemCollection);
          return itemCollection;
        });
      }
    }, {
      key: "requestRefresh",
      value: function requestRefresh() {
        return Promise.resolve();
      }
    }, {
      key: "onItemCollectionUpdated",
      value: function onItemCollectionUpdated(cb) {
        this.on('itemCollectionUpdated', cb);
      }
    }]);
  }();
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/rpc/StationDashboardService.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Private**
 * @module nmodule/nss/rc/rpc/StationDashboardService
 */
define(['Promise', 'nmodule/js/rc/tinyevents/tinyevents', 'nmodule/nss/rc/rpc/rpc'], function (Promise, tinyevents, rpc) {
  'use strict';

  /**
   * @class
   * @alias module:nmodule/nss/rc/rpc/StationDashboardService
   * @implements module:nmodule/nss/rc/rpc/rpc.IDashboardService
   * @mixes tinyevents
   */
  return /*#__PURE__*/function () {
    function StationDashboardService() {
      _classCallCheck(this, StationDashboardService);
      tinyevents(this);
    }
    return _createClass(StationDashboardService, [{
      key: "getSourceCollection",
      value: function getSourceCollection(ord) {
        return rpc.getStationData(ord);
      }
    }, {
      key: "getItemCollection",
      value: function getItemCollection(ord) {
        var _this = this;
        return rpc.getStationItemCollection(ord).then(function (itemCollection) {
          _this.emit('itemCollectionUpdated', itemCollection);
          return itemCollection;
        });
      }
    }, {
      key: "requestRefresh",
      value: function requestRefresh() {
        return Promise.resolve();
      }
    }, {
      key: "onItemCollectionUpdated",
      value: function onItemCollectionUpdated(cb) {
        this.on('itemCollectionUpdated', cb);
      }
    }]);
  }();
});
